/**
 * Gulp tasks for e2e testing TypeScript.
 */
const display = require("./util/display");
const uc = require("./util/unite-config");
const gulp = require("gulp");
const util = require("util");
const path = require("path");
const del = require("del");
const runSequence = require("run-sequence");
require("./e2e-transpile");
require("./e2e-runner");
require("./e2e-lint");
require("./e2e-install");

gulp.task("e2e-clean", async () => {
    const uniteConfig = await uc.getUniteConfig();

    const toClean = [
        path.join(uniteConfig.directories.e2eTestDist, "**/*.spec.js"),
        path.join(uniteConfig.directories.reports, "e2e/")
    ];
    display.info("Cleaning", toClean);
    return del(toClean);
});

gulp.task("e2e-post-clean", async () => {
    const uniteConfig = await uc.getUniteConfig();

    const toClean = [path.join(uniteConfig.directories.reports, "e2etemp/")];
    display.info("Cleaning", toClean);
    return del(toClean);
});

gulp.task("e2e", async () => {
    try {
        await util.promisify(runSequence)(
            "e2e-clean",
            "e2e-lint",
            "e2e-transpile",
            "e2e-serve",
            "e2e-run-test",
            "e2e-post-clean");
    } catch (err) {
        display.error("Unhandled error during task", err);
        process.exit(1);
    }
});

/* Generated by UniteJS */
