/**
 * Gulp tasks for e2e testing TypeScript.
 */
const display = require("./util/display");
const uc = require("./util/unite-config");
const asyncUtil = require("./util/async-util");
const gulp = require("gulp");
const typescript = require("gulp-typescript");
const sourcemaps = require("gulp-sourcemaps");

gulp.task("e2e-transpile", async () => {
    display.info("Running", "TypeScript");

    const uniteConfig = await uc.getUniteConfig();

    const tsProject = typescript.createProject("tsconfig.json", {"module": "commonjs"});
    let errorCount = 0;

    return asyncUtil.stream(gulp.src(`${uniteConfig.directories.e2eTestSrc}**/*.spec.{ts,tsx}`)
        .pipe(sourcemaps.init())
        .pipe(tsProject())
        .on("error", () => {
            errorCount++;
        })
        .js
        .pipe(sourcemaps.write({"includeContent": true}))
        .pipe(gulp.dest(uniteConfig.directories.e2eTestDist))
        .on("end", () => {
            if (errorCount > 0) {
                process.exit();
            }
        }));
});

/* Generated by UniteJS */
