/**
 * Gulp utils for unite configuration.
 */
const display = require("./display");
const minimist = require("minimist");
const fs = require("fs");
const util = require("util");

async function getUniteConfig () {
    try {
        const data = await util.promisify(fs.readFile)("./unite.json");
        return JSON.parse(data.toString());
    } catch (err) {
        display.error("Reading unite.json", err);
        process.exit(1);
        return undefined;
    }
}

async function getUniteThemeConfig () {
    try {
        const data = await util.promisify(fs.readFile)("./assetsSource/theme/unite-theme.json");
        return JSON.parse(data.toString());
    } catch (err) {
        display.error("Reading unite-theme.json", err);
        process.exit(1);
        return undefined;
    }
}

async function setUniteThemeConfig (uniteThemeConfig) {
    try {
        await util.promisify(fs.writeFile)("./assetsSource/theme/unite-theme.json",
            JSON.stringify(uniteThemeConfig, undefined, "\t"));
    } catch (err) {
        display.error("Writing unite-theme.json", err);
        process.exit(1);
    }
}

function getBuildConfiguration (uniteConfig, showInfo) {
    const knownOptions = {
        "default": {"buildConfiguration": "dev"},
        "string": ["buildConfiguration"]
    };

    const options = minimist(process.argv.slice(2), knownOptions);

    let buildConfiguration = null;

    if (uniteConfig &&
        uniteConfig.buildConfigurations &&
        uniteConfig.buildConfigurations[options.buildConfiguration]) {
        buildConfiguration = uniteConfig.buildConfigurations[options.buildConfiguration];
        if (showInfo) {
            display.info("Build Configuration", options.buildConfiguration);
        }
    } else {
        display.error(`Unknown build configuration '${options.buildConfiguration}' in unite.json, aborting.`);
        process.exit(1);
    }

    buildConfiguration = buildConfiguration || {};
    if (buildConfiguration.bundle === undefined) {
        buildConfiguration.bundle = false;
    }
    if (buildConfiguration.sourcemaps === undefined) {
        buildConfiguration.sourcemaps = true;
    }
    if (buildConfiguration.minify === undefined) {
        buildConfiguration.minify = false;
    }
    if (buildConfiguration.variables === undefined) {
        buildConfiguration.variables = {};
    }
    buildConfiguration.variables.name = options.buildConfiguration;
    if (showInfo) {
        display.info("Sourcemaps", buildConfiguration.sourcemaps);
        display.info("Minify", buildConfiguration.minify);
        display.info("Bundle", buildConfiguration.bundle);
    }

    return buildConfiguration;
}

module.exports = {
    getBuildConfiguration,
    getUniteConfig,
    getUniteThemeConfig,
    setUniteThemeConfig
};

/* Generated by UniteJS */
